@@ -46,7 +46,7 @@ Battery::Battery(QObject *parent, const QVariantList &args)
       m_theme(0),
       m_animId(-1),
       m_alpha(1),
-      m_fadeIn(true),
+      m_fadeIn(false),
       m_acAnimId(-1),
       m_acAlpha(1),
       m_acFadeIn(false),
@@ -108,7 +108,7 @@ void Battery::init()
 
 void Battery::constraintsEvent(Plasma::Constraints constraints)
 {
-    if (constraints & Plasma::FormFactorConstraint | Plasma::SizeConstraint) {
+    if (constraints & (Plasma::FormFactorConstraint | Plasma::SizeConstraint)) {
         if (formFactor() == Plasma::Vertical) {
             setMaximumSize(QWIDGETSIZE_MAX, qMax(m_textRect.height(), contentsRect().width()));
             //kDebug() << "Vertical FormFactor";
@@ -551,6 +551,11 @@ void Battery::connectSources() {
     }
 
     dataEngine("powermanagement")->connectSource(I18N_NOOP("AC Adapter"), this);
+
+    connect(dataEngine("powermanagement"), SIGNAL(sourceAdded(QString)),
+            this,                          SLOT(sourceAdded(QString)));
+    connect(dataEngine("powermanagement"), SIGNAL(sourceRemoved(QString)),
+            this,                          SLOT(sourceRemoved(QString)));
 }
 
 void Battery::disconnectSources()
@@ -562,6 +567,26 @@ void Battery::disconnectSources()
     }
 
     dataEngine("powermanagement")->disconnectSource(I18N_NOOP("AC Adapter"), this);
+
+    disconnect(SLOT(sourceAdded(QString)));
+    disconnect(SLOT(sourceRemoved(QString)));
+}
+
+void Battery::sourceAdded(const QString& source)
+{
+    if (source.startsWith("Battery") && source != "Battery") {
+        dataEngine("powermanagement")->connectSource(source, this);
+        m_numOfBattery++;
+    }
+}
+
+void Battery::sourceRemoved(const QString& source)
+{
+    if (m_batteries_data.contains(source)) {
+        m_batteries_data.remove(source);
+        m_numOfBattery--;
+        update();
+    }
 }
 
 #include "battery.moc"
